@@ -163,8 +163,8 @@ class Set(WMLResource):
                     return "SUCCESS"
 
             else:
-                print("Project id can not be None. ")
-                return "FAILURE"
+                error_msg = "Project id cannot be None."
+                raise CannotSetProjectOrSpace(reason=error_msg)
         else:
             self._client.default_project_id = project_id
 
