@@ -41,60 +41,28 @@ class Connections(WMLResource):
 
         WMLResource._validate_type(response_data, u'connection_response', dict)
         try:
+            new_el = {'metadata': {'id': response_data['metadata']['asset_id'],
+                                   'asset_type': response_data['metadata']['asset_type'],
+                                   'create_time': response_data['metadata']['create_time'],
+                                   'last_access_time': response_data['metadata']['usage'].get('last_access_time')
+                                   },
+                      'entity': {
+                          'datasource_type': response_data['entity']['datasource_type'],
+                          'name': response_data['entity']['name']
+                      }
+                      }
+
+            for el in ['description', 'origin_country', 'owner_id', 'properties']:
+                if el in response_data['entity']:
+                    new_el['entity'][el] = response_data['entity'].get(el)
+
             if self._client.default_space_id is not None:
-                new_el = {'metadata': {'id': response_data['metadata']['asset_id'],
-                                       'space_id': response_data['metadata']['space_id'],
-                                       'asset_type': response_data['metadata']['asset_type'],
-                                       'create_time': response_data['metadata']['create_time'],
-                                       'last_access_time': response_data['metadata']['usage'].get('last_access_time')
-                                       },
-                          'entity': {
-                              'datasource_type': response_data['entity']['datasource_type'],
-                              'description': response_data['entity']['description'],
-                              'name': response_data['entity']['name'],
-                              'origin_country': response_data['entity']['origin_country'],
-                              'owner_id': response_data['entity']['owner_id'],
-                              'properties': response_data['entity']['properties']
-                                }
-                          }
+                new_el['metadata']['space_id'] = response_data['metadata']['space_id']
+
             elif self._client.default_project_id is not None:
-                if self._client.WSD:
-                    # TODO :  There is no owner id in connection api response of WSD1.0, this might need a check in WSD2.0
-                    # kaganesa: add the below line in 2.0
-                    #  'owner_id': response_data['entity']['owner_id'],
-                    new_el = {'metadata': {'id': response_data['metadata']['asset_id'],
-                                           'project_id': response_data['metadata']['project_id'],
-                                           'asset_type': response_data['metadata']['asset_type'],
-                                           'create_time': response_data['metadata']['create_time'],
-                                           'last_access_time': response_data['metadata']['usage'].get('last_access_time')
-                                           },
-                              'entity': {
-                                  'datasource_type': response_data['entity']['datasource_type'],
-                                  'description': response_data['entity']['description'],
-                                  'name': response_data['entity']['name'],
-                                  'origin_country': response_data['entity']['origin_country'],
-                                 # 'owner_id': response_data['entity']['owner_id'],
-                                  'properties': response_data['entity']['properties']
-                               }
-                              }
+                new_el['metadata']['project_id'] = response_data['metadata']['project_id']
 
-
-                else:
-                    new_el = {'metadata': {'id': response_data['metadata']['asset_id'],
-                                           'project_id': response_data['metadata']['project_id'],
-                                           'asset_type': response_data['metadata']['asset_type'],
-                                           'create_time': response_data['metadata']['create_time'],
-                                           'last_access_time': response_data['metadata']['usage'].get('last_access_time')
-                                           },
-                              'entity': {
-                                  'datasource_type': response_data['entity']['datasource_type'],
-                                  'description': response_data['entity']['description'],
-                                  'name': response_data['entity']['name'],
-                                  'origin_country': response_data['entity']['origin_country'],
-                                  'owner_id': response_data['entity']['owner_id'],
-                                  'properties': response_data['entity']['properties']
-                                  }
-                              }
+                if not self._client.WSD:
                     if 'href' in response_data['metadata']:
                         if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
                             href_without_host = response_data['href'].split('.com')[-1]
