@@ -29,7 +29,8 @@ from ..utils.autoai.utils import (prepare_auto_ai_model_to_publish, prepare_auto
                                   prepare_auto_ai_model_to_publish_notebook_normal_scenario,
                                   download_wml_pipeline_details_from_file, get_sw_spec_and_type_based_on_sklearn)
 from ..utils.deployment.errors import (WrongDeploymnetType, ModelTypeNotSupported, NotAutoAIExperiment,
-                                       DeploymentNotSupported, MissingSpace, ModelPromotionFailed)
+                                       DeploymentNotSupported, MissingSpace, ModelPromotionFailed,
+                                       ServingNameNotAvailable)
 from ..helpers import DataConnection
 from ..wml_client_error import ApiRequestFailure
 from ..workspace import WorkSpace
@@ -95,15 +96,19 @@ class BaseDeployment(ABC):
 
         if target_wml_credentials is None:
             if isinstance(source_wml_credentials, WorkSpace):
-                self._target_workspace = source_wml_credentials
+                self._target_workspace = WorkSpace(wml_credentials=source_wml_credentials.wml_credentials,
+                                                   space_id=target_space_id if target_space_id is not None else source_wml_credentials.space_id)
 
             elif isinstance(source_wml_credentials, dict):
                 self._target_workspace = WorkSpace(wml_credentials=source_wml_credentials.copy(),
-                                                   project_id=source_project_id,
-                                                   space_id=source_space_id)
+                                                   space_id=target_space_id if target_space_id is not None else source_space_id)
             else:
                 self._target_workspace = None
 
+            if target_space_id or target_project_id:
+                self._target_workspace.project_id = target_project_id
+                self._target_workspace.space_id = target_space_id
+
         else:
             if isinstance(target_wml_credentials, WorkSpace):
                 self._target_workspace = target_wml_credentials
@@ -165,6 +170,20 @@ class BaseDeployment(ABC):
             ID of a training/experiment (only applicable for AutoAI deployments)
         """
 
+        if kwargs.get('serving_name'):
+            url = self._source_workspace.wml_client.service_instance._href_definitions.get_deployments_href() + f"/serving_name/{kwargs.get('serving_name')}"
+            res = requests.get(url,
+                               headers=self._source_workspace.wml_client._get_headers(),
+                               params=self._source_workspace.wml_client._params(),
+                               verify=not self._source_workspace.wml_client.ICP)
+
+            if res.status_code == 404:
+                pass  # endpoint for checking availability is not available on this cluster
+            else:
+                result = self._source_workspace.wml_client.repository._handle_response(200, 'checking serving name availability', res)
+                if not result['available']:
+                    raise ServingNameNotAvailable(result['message'])
+
         # note: This section is only for deployments with specified experiment_id
         if kwargs['experiment_run_id'] is not None:
             run_params = self._source_workspace.wml_client.training.get_details(
@@ -657,30 +676,18 @@ class BaseDeployment(ABC):
         @wraps(method)
         def _method(self, *method_args, **method_kwargs):
             with redirect_stdout(open(os.devnull, "w")):
-                self._target_workspace.wml_client.set.default_space(
-                    self._target_workspace.space_id) if self._target_workspace.wml_client.ICP else None
+                if self._target_workspace.space_id is not None:
+                    self._target_workspace.wml_client.set.default_space(
+                        self._target_workspace.space_id) if self._target_workspace.wml_client.ICP else None
 
             try:
-                method_output = method(self, *method_args, **method_kwargs)
+                return method(self, *method_args, **method_kwargs)
 
-            except Exception as e:
-                if not self._target_workspace.WMLS:
+            finally:
+                if not self._target_workspace.WMLS and self._target_workspace.project_id:
                     with redirect_stdout(open(os.devnull, "w")):
-                        try:
+                        if self._target_workspace.project_id is not None:
                             self._target_workspace.wml_client.set.default_project(
                                 self._target_workspace.project_id) if self._target_workspace.wml_client.ICP else None
-                        except:
-                            pass
-                raise e
-
-            else:
-                if not self._target_workspace.WMLS:
-                    with redirect_stdout(open(os.devnull, "w")):
-                        try:
-                            self._target_workspace.wml_client.set.default_project(
-                                self._target_workspace.project_id) if self._target_workspace.wml_client.ICP else None
-                        except:
-                            pass
-            return method_output
 
         return _method
