@@ -27,7 +27,7 @@ from ibm_watson_machine_learning.utils.autoai.enums import (
 from ibm_watson_machine_learning.utils.autoai.errors import (
     FitNotCompleted, MissingDataPreprocessingStep, WrongDataJoinGraphNodeName, DataSourceSizeNotSupported,
     TrainingDataSourceIsNotFile, NoneDataConnection, PipelineNotLoaded, OBMForNFSIsNotSupported,
-    ForecastingUnsupportedOperation, LibraryNotCompatible, InvalidDataAsset)
+    ForecastingUnsupportedOperation, LibraryNotCompatible, InvalidDataAsset, TestDataNotPresent)
 from ibm_watson_machine_learning.utils.autoai.utils import try_import_lale, all_logging_disabled
 from ibm_watson_machine_learning.utils.autoai.wsd_ui import (
     save_computed_pipelines_for_ui, save_experiment_for_ui, save_metadata_for_ui)
@@ -148,6 +148,9 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  obm_pod_version=None,
                  text_columns_names=None,
                  n_parallel_data_connections=None,
+                 test_data_csv_separator: Union[List[str], str] = ',',
+                 test_data_excel_sheet: Union[str, int] = 0,
+                 test_data_encoding: str = 'utf-8',
                  # sampling_type=None,  #TODO: Uncomment to add sampling_type support
                  # fairness_info=None,  TODO: uncomment to add fairness info
                  **kwargs):
@@ -186,6 +189,9 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             'text_columns_names': text_columns_names,
             # 'sampling_type': sampling_type, #TODO: Uncomment to add sampling_type support
             'n_parallel_data_connections': n_parallel_data_connections,
+            'test_data_csv_separator': test_data_csv_separator,
+            'test_data_excel_sheet': test_data_excel_sheet,
+            'test_data_encoding': test_data_encoding,
         }
         self._engine: 'WMLEngine' = engine
         self._engine.initiate_remote_resources(params=self.params, **kwargs)
@@ -248,7 +254,8 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             *,
             training_data_reference: List['DataConnection'],
             training_results_reference: 'DataConnection' = None,
-            background_mode=False) -> dict:
+            background_mode=False,
+            test_data_references: List['DataConnection'] = None) -> dict:
         """
         Run a training process on WML of autoai on top of the training data referenced by DataConnection.
 
@@ -263,6 +270,9 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         background_mode: bool, optional
             Indicator if fit() method will run in background (async) or (sync).
 
+        test_data_references: List[DataConnection], optional
+            Data storage connection details to inform where test / holdout data is stored.
+
         Returns
         -------
         Dictionary with run details.
@@ -303,6 +313,8 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             raise NoneDataConnection('training_data_reference')
 
         for conn in training_data_reference:
+            if self._workspace.wml_client.project_type == 'local_git_storage':
+                conn.location.userfs = True
             conn._wml_client = self._workspace.wml_client
             # TODO: remove S3 implementation
             if conn.type == DataConnectionTypes.S3:
@@ -311,6 +323,19 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         training_data_reference = [new_conn for conn in training_data_reference for new_conn in
                                    conn._subdivide_connection()]
 
+        if isinstance(test_data_references, list):
+            for conn in test_data_references:
+                # Update test data ref with client object, experiment parameters
+                if isinstance(conn, DataConnection):
+                    if self._workspace.wml_client.project_type == 'local_git_storage':
+                        conn.location.userfs = True
+                    conn._wml_client = self._workspace.wml_client
+                    # TODO: remove S3 implementation
+                    if conn.type == DataConnectionTypes.S3:
+                        conn._validate_cos_resource()
+
+                    conn.auto_pipeline_params = self._engine._auto_pipelines_parameters
+
         # note: check if DataJoinGraph node names are correct and equivalent
         # to training DataConnections IDs/data_join_node_names
         if self.params['data_join_graph']:
@@ -417,11 +442,12 @@ class RemoteAutoPipelines(BaseAutoPipelines):
 
         run_params = self._engine.fit(training_data_reference=training_data_reference,
                                       training_results_reference=training_results_reference,
-                                      background_mode=background_mode)
+                                      background_mode=background_mode,
+                                      test_data_references=test_data_references)
 
         if isinstance(training_data_reference[0].location, WSDAssetLocation) or (
-                isinstance(training_data_reference[0].location, AssetLocation) and training_data_reference[
-            0].location._wsd):
+                isinstance(training_data_reference[0].location, AssetLocation
+                           ) and training_data_reference[0].location._wsd):
             try:
                 wml_pipeline_details = self._workspace.wml_client.pipelines.get_details(
                     run_params['entity']['pipeline']['id'])
@@ -671,6 +697,13 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         -------
         List['DataConnection'] with populated optimizer parameters
         """
+        user_holdout_exists = True
+        try:
+            self.get_test_data_connections()
+
+        except TestDataNotPresent:
+            user_holdout_exists = False
+
         optimizer_parameters = self.get_params()
         training_data_references = self.get_run_details()['entity']['training_data_references']
 
@@ -681,6 +714,38 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             data_connection.auto_pipeline_params = deepcopy(optimizer_parameters)
             data_connection._wml_client = self._engine._wml_client
             data_connection._run_id = self._engine._current_run_id
+            data_connection._user_holdout_exists = user_holdout_exists
+
+        return data_connections
+
+    def get_test_data_connections(self) -> List['DataConnection']:
+        """
+        Create DataConnection objects for further user usage
+            (To recreate autoai holdout that user specified).
+
+        Returns
+        -------
+        List['DataConnection'] with populated optimizer parameters
+        """
+        optimizer_parameters = self.get_params()
+        run_details = self.get_run_details()
+
+        if 'test_data_references' not in run_details['entity']:
+            raise TestDataNotPresent(reason="User specified test data was not present in this experiment. "
+                                            "Try to use 'with_holdout_split' parameter for original "
+                                            "training_data_references to retrieve test data.")
+
+        test_data_references = run_details['entity']['test_data_references']
+
+        data_connections = [
+            DataConnection._from_dict(_dict=data_connection) for data_connection in test_data_references]
+
+        for data_connection in data_connections:  # note: populate DataConnections with optimizer params
+            data_connection.auto_pipeline_params = deepcopy(optimizer_parameters)
+            data_connection._wml_client = self._engine._wml_client
+            data_connection._run_id = self._engine._current_run_id
+            data_connection._test_data = True
+            data_connection._user_holdout_exists = True
 
         return data_connections
 
@@ -748,6 +813,17 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             raise MissingDataPreprocessingStep(
                 reason="Cannot get preprocessed data as preprocessing step was not performed.")
 
+    def get_preprocessed_test_data_connection(self) -> 'DataConnection':
+        """
+        Create DataConnection object for further user usage (with OBM output)
+            (eg. to handle data storage connection or to recreate autoai holdout split).
+
+        Returns
+        -------
+        DataConnection with populated optimizer parameters
+        """
+        raise NotImplementedError("This functionality is not yet implemented.")
+
     def get_preprocessing_pipeline(self) -> 'DataJoinPipeline':
         """
         Returns preprocessing pipeline object for further usage.
