@@ -316,14 +316,16 @@ class BaseDataConnection(ABC):
                         self.connection = S3Connection(
                             api_key=connection_details['entity']['properties'].get('api_key'),
                             auth_endpoint=connection_details['entity']['properties'].get('iam_url'),
-                            endpoint_url=connection_details['entity']['properties'].get('url')
+                            endpoint_url=connection_details['entity']['properties'].get('url'),
+                            _internal_use=True
                         )
 
                     else:
                         self.connection = S3Connection(
                             endpoint_url=connection_details['entity']['properties'].get('url'),
                             access_key_id=connection_details['entity']['properties'].get('access_key'),
-                            secret_access_key=connection_details['entity']['properties'].get('secret_key')
+                            secret_access_key=connection_details['entity']['properties'].get('secret_key'),
+                            _internal_use=True
                         )
 
                 else:
