@@ -48,9 +48,11 @@ from ibm_watson_machine_learning.utils.autoai.enums import PredictionType, DataC
 from ibm_watson_machine_learning.utils.autoai.errors import (
     MissingAutoPipelinesParameters, UseWMLClient, MissingCOSStudioConnection, MissingProjectLib,
     HoldoutSplitNotSupported, InvalidCOSCredentials, MissingLocalAsset, InvalidIdType, NotWSDEnvironment,
-    NotExistingCOSResource, InvalidDataAsset, CannotReadSavedRemoteDataBeforeFit
+    NotExistingCOSResource, InvalidDataAsset, CannotReadSavedRemoteDataBeforeFit, NoAutomatedHoldoutSplit
 )
-from ibm_watson_machine_learning.utils.autoai.utils import all_logging_disabled
+
+import numpy as np
+from ibm_watson_machine_learning.utils.autoai.utils import all_logging_disabled, try_import_autoai_libs
 from ibm_watson_machine_learning.utils.autoai.watson_studio import get_project
 from ibm_watson_machine_learning.wml_client_error import MissingValue, ApiRequestFailure
 from .base_connection import BaseConnection
@@ -160,6 +162,8 @@ class DataConnection(BaseDataConnection):
         self._run_id = None
         self._obm = False
         self._obm_cos_path = None
+        self._test_data = False
+        self._user_holdout_exists = False
 
         # note: make data connection id as a location path for OBM + KB
         if data_join_node_name is None:
@@ -359,108 +363,79 @@ class DataConnection(BaseDataConnection):
 
         return data_connection
 
-    def read_indices(self, indices_location: str = None, **kwargs):
-        training_details = self._wml_client.training.get_details(self.auto_pipeline_params['run_id'])
-        # TODO indices location should be read from response, than constructed
-        if indices_location is not None:    # when location is provided from metadata
-            holdout_data_indices_location = indices_location
+    def _recreate_holdout(
+            self,
+            data: 'DataFrame'
+    ) -> Union[Tuple['DataFrame', 'DataFrame'], Tuple['DataFrame', 'DataFrame', 'DataFrame', 'DataFrame']]:
+        """This method tries to recreate holdout data."""
+        try_import_autoai_libs(minimum_version='1.12.14')
+        from autoai_libs.utils.holdout_utils import make_holdout_split, numpy_split_on_target_values
+        from autoai_libs.utils.sampling_utils import numpy_sample_rows
+
+        data.replace([np.inf, -np.inf], np.nan, inplace=True)
+        data.drop_duplicates(inplace=True)
+        data.dropna(subset=[self.auto_pipeline_params['prediction_column']], inplace=True)
+        dfy = DataFrame(data[self.auto_pipeline_params['prediction_column']])
+        data.drop(columns=[self.auto_pipeline_params['prediction_column']], inplace=True)
+
+        y_column = dfy.columns
+        X_columns = data.columns
+
+        if self._test_data:
+            return data, dfy
 
         else:
+            ############################
+            #   REMOVE MISSING ROWS    #
+            from autoai_libs.utils.holdout_utils import numpy_remove_missing_target_rows
+            # Remove (and save) the rows of X and y for which the target variable has missing values
+            data, dfy, _, _, _, _ = numpy_remove_missing_target_rows(
+                y=dfy.values[:, 0], X=data.values
+            )
+            #   End of REMOVE MISSING ROWS    #
+            ###################################
+
+            #################
+            #   SAMPLING    #
+            # Get a sample of the rows if requested and applicable
+            # (check for sampling is performed inside this function)
             try:
-                holdout_data_indices_location = training_details['entity']['status']['metrics'][0]['context']['intermediate_model']['holdout_data_indices_location']
-
-            except KeyError:
-                holdout_data_indices_location = \
-                training_details['entity']['status']['metrics'][0]['context']['intermediate_model']['schema_location']
-                holdout_data_indices_location = '/'.join(
-                    holdout_data_indices_location.split('/')[:-3]) + '/holdout_data_indices.tar.gz'
-
-        data = DataFrame()
-
-        # TODO: Remove S3 implementation
-        if self.type == DataConnectionTypes.S3:
-            warn(message="S3 DataConnection is deprecated! Please use data_asset_id instead.")
-
-            cos_client = self._init_cos_client()
-
-            try:
-                data = self._download_indices_from_cos(cos_client=cos_client,
-                                                       location_path=holdout_data_indices_location)
-
-            except Exception as cos_access_exception:
-                raise ConnectionError(
-                    f"Unable to access data object in cloud object storage with credentials supplied. "
-                    f"Error: {cos_access_exception}")
-
-        elif self.type == DataConnectionTypes.DS:
-            try:
-                if self._check_if_connection_asset_is_s3():
-                    cos_client = self._init_cos_client()
-                    data = self._download_indices_from_cos(cos_client=cos_client,
-                                                           location_path=holdout_data_indices_location)
-                else:
-                    # TODO Prepare actual solution
-                    raise Exception('Not supported yet')
-                    # data = self._download_training_data_from_data_asset_storage()
-
-            except NotImplementedError as e:
-                raise e
-
-            except FileNotFoundError as e:
-                raise e
-
-            except Exception:
-                data_location = self.location.to_dict().copy()
-                data_location.update({'type': self.type, 'path': holdout_data_indices_location})
-
-                try_import_pyarrow()
-
-                flight_service = FlightService(
-                    wml_client=self._wml_client,
-                    params=self.auto_pipeline_params,
-                    data_location=data_location,
-                    experiment_metadata=kwargs.get('experiment_metadata')
+                data, dfy, _ = numpy_sample_rows(
+                    X=data,
+                    y=dfy,
+                    train_sample_rows_test_size=self.auto_pipeline_params['train_sample_rows_test_size'],
+                    learning_type=self.auto_pipeline_params['prediction_type'],
+                    return_sampled_indices=True
                 )
 
-                data = flight_service.read()
+            # Note: we have a silent error here (the old core behaviour)
+            # sampling is not performed as 'train_sample_rows_test_size' is bigger than data rows count
+            # TODO: can we throw an error instead?
+            except ValueError as e:
+                if 'between' in str(e):
+                    pass
 
-        elif self.type == DataConnectionTypes.FS:
+                else:
+                    raise e
+            #   End of SAMPLING    #
+            ########################
 
-            data = self._download_indices_from_file_system(location_path=holdout_data_indices_location)
+            # Perform holdout split
+            X_train, X_holdout, y_train, y_holdout, _, _ = make_holdout_split(
+                x=data,
+                y=dfy,
+                learning_type=self.auto_pipeline_params['prediction_type'],
+                fairness_info=self.auto_pipeline_params.get('fairness_info', None),
+                test_size=self.auto_pipeline_params['holdout_size'],
+                return_only_holdout=False
+            )
 
-        elif self.type == DataConnectionTypes.CA or self.type == DataConnectionTypes.CN:
-            if self._check_if_connection_asset_is_s3():
-                cos_client = self._init_cos_client()
+            X_train = DataFrame(X_train, columns=X_columns)
+            X_holdout = DataFrame(X_holdout, columns=X_columns)
+            y_train = DataFrame(y_train, columns=y_column)
+            y_holdout = DataFrame(y_holdout, columns=y_column)
 
-                try:
-                    data = self._download_indices_from_cos(cos_client=cos_client,
-                                                           location_path=holdout_data_indices_location)
-
-                except Exception as cos_access_exception:
-                    raise ConnectionError(
-                        f"Unable to access data object in cloud object storage with credentials supplied. "
-                        f"Error: {cos_access_exception}")
-            else:
-                try:
-                    # TODO Prepare actual solution
-                    # data = self._download_data_from_nfs_connection()
-                    raise Exception('Not supported yet')
-
-                except Exception:
-                    try_import_pyarrow()
-
-                    flight_service = FlightService(
-                        wml_client=self._wml_client,
-                        params=self.auto_pipeline_params,
-                        data_location={'location': holdout_data_indices_location,
-                                       'type': self.type,
-                                       "connection": self.connection.to_dict()},
-                        experiment_metadata=kwargs.get('experiment_metadata')
-                    )
-
-                    data = flight_service.read()
-
-        return data
+            return X_train, X_holdout, y_train, y_holdout
 
     def read(self,
              with_holdout_split: bool = False,
@@ -487,16 +462,58 @@ class DataConnection(BaseDataConnection):
 
         Returns
         -------
-        pandas.DataFrame contains dataset from remote data storage or Tuple[pandas.DataFrame, pandas.DataFrame]
-            containing training data and holdout data from remote storage
-            (only if only_holdout == True and auto_pipeline_params was passed)
+        pandas.DataFrame contains dataset from remote data storage : Xy_train
+        or
+        Tuple[pandas.DataFrame, pandas.DataFrame, pandas.DataFrame, pandas.DataFrame] : X_train, X_holdout, y_train, y_holdout
+        or
+        Tuple[pandas.DataFrame, pandas.DataFrame] : X_test, y_test
+        containing training data and holdout data from remote storage.
+
+
+        Example
+        -------
+        Auto holdout split from backend (only train data provided)
+        >>> train_data_connections = optimizer.get_data_connections()
+        >>>
+        >>> data = train_data_connections[0].read() # all train data
+        >>> # or
+        >>> X_train, X_holdout, y_train, y_holdout = train_data_connections[0].read(with_holdout_split=True) # train and holdout data
+
+        User provided train and test data
+        >>> optimizer.fit(training_data_reference=[DataConnection],
+        >>>               training_results_reference=DataConnection,
+        >>>               test_data_reference=DataConnection)
+        >>>
+        >>> test_data_connection = optimizer.get_test_data_connections()
+        >>> X_test, y_test = test_data_connection.read() # only holdout data
+        >>>
+        >>> # and
+        >>>
+        >>> train_data_connections = optimizer.get_data_connections()
+        >>> data = train_connections[0].read() # only train data
         """
+        if with_holdout_split and self._user_holdout_exists:  # when this connection is training one
+            raise NoAutomatedHoldoutSplit(reason="Experiment was run based on user defined holdout dataset.")
+
         # note: experiment metadata is used only in autogen notebooks
         experiment_metadata = kwargs.get('experiment_metadata')
         if experiment_metadata is not None:
-            csv_separator = experiment_metadata.get('csv_separator', csv_separator)
-            excel_sheet = experiment_metadata.get('excel_sheet', excel_sheet)
-            encoding = experiment_metadata.get('encoding', encoding)
+            self.auto_pipeline_params['train_sample_rows_test_size'] = experiment_metadata.get(
+                'train_sample_rows_test_size')
+            self.auto_pipeline_params['prediction_column'] = experiment_metadata['prediction_column']
+            self.auto_pipeline_params['holdout_size'] = experiment_metadata['holdout_size']
+            self.auto_pipeline_params['prediction_type'] = experiment_metadata['prediction_type']
+            self.auto_pipeline_params['fairness_info'] = experiment_metadata.get('fairness_info', None)
+
+            if self._test_data:
+                csv_separator = experiment_metadata.get('test_data_csv_separator', csv_separator)
+                excel_sheet = experiment_metadata.get('test_data_excel_sheet', excel_sheet)
+                encoding = experiment_metadata.get('test_data_encoding', encoding)
+
+            else:
+                csv_separator = experiment_metadata.get('csv_separator', csv_separator)
+                excel_sheet = experiment_metadata.get('excel_sheet', excel_sheet)
+                encoding = experiment_metadata.get('encoding', encoding)
 
         if self.type == DataConnectionTypes.DS or self.type == DataConnectionTypes.CA:
             if self._wml_client is None:
@@ -506,19 +523,7 @@ class DataConnection(BaseDataConnection):
                 except ModuleNotFoundError:
                     raise NotImplementedError(f"This functionality can be run only on Watson Studio.")
 
-        indices = None
-        if with_holdout_split:
-            try:
-                indices = self.read_indices(
-                    indices_location=experiment_metadata.get('holdout_data_indices_location'))
-
-            except Exception as e:
-                print("\"with_holdout_split\" option is deprecated.")
-                warn("\"with_holdout_split\" option is deprecated.")
-
-        from sklearn.model_selection import train_test_split
-
-        if with_holdout_split and not self.auto_pipeline_params.get('prediction_type', False):
+        if (with_holdout_split or self._test_data) and not self.auto_pipeline_params.get('prediction_type', False):
             raise MissingAutoPipelinesParameters(
                 self.auto_pipeline_params,
                 reason=f"To be able to recreate an original holdout split, you need to schedule a training job or "
@@ -648,54 +653,16 @@ class DataConnection(BaseDataConnection):
         if isinstance(data, DataFrame) and 'Unnamed: 0' in data.columns.tolist():
             data.drop(['Unnamed: 0'], axis=1, inplace=True)
 
-        # note: this code is deprecated, user information isa provided at the beginning.
-        if with_holdout_split:
-            if not isinstance(data, DataFrame):
-                raise HoldoutSplitNotSupported(
-                    None,
-                    reason="SDK currently does not support a local holdout split with xlsx files without sheet_name "
-                           "provided.")
+        if self._test_data:  # when this data connection is a test / holdout one
+            test_X, test_y = self._recreate_holdout(data=data)
+            return test_X, test_y
 
-            if not self._obm and self.auto_pipeline_params.get('data_join_graph', False):
-                raise HoldoutSplitNotSupported(
-                    None,
-                    reason="Holdout split is not supported for not processed multiple input data. "
-                           "Please use \"get_preprocessed_data().read(with_holdout_split=True)\"")
+        elif with_holdout_split:  # when this connection is training one
+            X_train, X_holdout, y_train, y_holdout = self._recreate_holdout(data=data)
+            return X_train, X_holdout, y_train, y_holdout
 
-            if self.auto_pipeline_params.get('train_sample_rows_test_size'):
-                pass
-
-            is_classification = self.auto_pipeline_params['prediction_type'] == PredictionType.BINARY \
-                                or self.auto_pipeline_params['prediction_type'] == PredictionType.MULTICLASS \
-                                or self.auto_pipeline_params['prediction_type'] == 'classification'
-
-            # note: 'classification' check left for backward compatibility
-            if indices is None:
-                x, x_holdout, y, y_holdout = train_test_split(
-                    data.drop([self.auto_pipeline_params['prediction_column']], axis=1),
-                    data[self.auto_pipeline_params['prediction_column']].values,
-                    test_size=self.auto_pipeline_params['holdout_size'],
-                    random_state=33,
-                    stratify=data[self.auto_pipeline_params['prediction_column']].values if is_classification else None)
-            else:
-                x_holdout = data.iloc[indices.values.flatten()].drop(self.auto_pipeline_params['prediction_column'],
-                                                                     axis=1)
-                y_holdout = data.iloc[indices.values.flatten()][self.auto_pipeline_params['prediction_column']].values
-                x = data.loc[set(data.index) - set(indices.values.flatten())].drop(
-                    self.auto_pipeline_params['prediction_column'], axis=1)
-                y = data.loc[set(data.index) - set(indices.values.flatten())][
-                    self.auto_pipeline_params['prediction_column']].values
-
-            data_train = DataFrame(data=x, columns=data.columns.tolist())
-            data_train[self.auto_pipeline_params['prediction_column']] = y
-
-            data_holdout = DataFrame(data=x_holdout, columns=data.columns.tolist())
-            data_holdout[self.auto_pipeline_params['prediction_column']] = y_holdout
-
-            return data_train, data_holdout
-        # --- end note
-
-        return data
+        else:
+            return data
 
     def write(self, data: Union[str, 'DataFrame'], remote_name: str = None, **kwargs) -> None:
         """
@@ -838,8 +805,9 @@ class S3Connection(BaseConnection):
     """
 
     def __init__(self, endpoint_url: str, access_key_id: str = None, secret_access_key: str = None,
-                 api_key: str = None, service_name: str = None, auth_endpoint: str = None) -> None:
-        warn(message="S3 DataConnection is deprecated! Please use data_asset_id instead.")
+                 api_key: str = None, service_name: str = None, auth_endpoint: str = None, _internal_use=False) -> None:
+        if not _internal_use:
+            warn(message="S3 DataConnection is deprecated! Please use data_asset_id instead.")
 
         if (access_key_id is None or secret_access_key is None) and (api_key is None or auth_endpoint is None):
             raise InvalidCOSCredentials(reason='You need to specify (access_key_id and secret_access_key) or'
