@@ -21,7 +21,8 @@ import json
 import sys
 import threading
 from typing import List, Optional, Iterable, TYPE_CHECKING
-from .errors import DataStreamError, WrongLocationProperty, FlightServiceInfoNotAvailable, WrongFileLocation, FileUploadFailed
+from .errors import DataStreamError, WrongLocationProperty, FlightServiceInfoNotAvailable, WrongFileLocation, \
+    FileUploadFailed
 from .utils import prepare_interaction_props_for_cos
 
 import pandas as pd
@@ -215,7 +216,7 @@ class FlightService:
             df = self._get_data(endpoint)
             row_size = sys.getsizeof(df.iloc[:2]) - sys.getsizeof(df.iloc[:1])
 
-            if row_size != 0:   # append batches only when we have data
+            if row_size != 0:  # append batches only when we have data
                 with self.lock_read:
                     if not self.stop_reading:
                         # note: what to do if we have batch too large (over 1 GB limit)
@@ -338,9 +339,11 @@ class FlightService:
 
             if 'bucket' in self.data_location['location']:
                 command['interaction_properties'] = prepare_interaction_props_for_cos(
-                    self.params, self.data_location['location']['path'])
+                    self.params, self.data_location['location'].get(
+                        'path', self.data_location['location']['file_name']))
                 command['interaction_properties']['infer_schema'] = "true"
-                command['interaction_properties']['file_name'] = self.data_location['location']['path']
+                command['interaction_properties']['file_name'] = self.data_location['location'].get(
+                    'path', self.data_location['location']['file_name'])
                 command['interaction_properties']['bucket'] = self.data_location['location']['bucket']
 
             elif 'schema_name' in self.data_location['location']:
@@ -380,7 +383,8 @@ class FlightService:
             command['interaction_properties'] = {}
 
             if 'bucket' in self.data_location['location']:
-                command['interaction_properties']['file_name'] = self.data_location['location']['path']
+                command['interaction_properties']['file_name'] = self.data_location['location'].get(
+                    'path', self.data_location['location']['file_name'])
                 command['interaction_properties']['bucket'] = self.data_location['location']['bucket']
 
             elif 'schema_name' in self.data_location['location']:
