@@ -58,15 +58,15 @@ class HwSpec(WMLResource):
         """
         HwSpec._validate_type(hw_spec_uid, u'hw_spec_uid', STR_TYPE, True)
         if not self._ICP:
-            response = requests.get(self._href_definitions.get_hw_spec_href(hw_spec_uid), params=self._client._params(skip_space_project_chk=True),
+            response = requests.get(self._client.service_instance._href_definitions.get_hw_spec_href(hw_spec_uid), params=self._client._params(skip_space_project_chk=True),
                                     headers=self._client._get_headers())
         else:
             if self._client.ICP_PLATFORM_SPACES:
-                response = requests.get(self._href_definitions.get_hw_spec_href(hw_spec_uid),
+                response = requests.get(self._client.service_instance._href_definitions.get_hw_spec_href(hw_spec_uid),
                                         params=self._client._params(skip_space_project_chk=True),
                                         headers=self._client._get_headers(), verify=False)
             else:
-                response = requests.get(self._href_definitions.get_hw_spec_href(hw_spec_uid), params=self._client._params(),
+                response = requests.get(self._client.service_instance._href_definitions.get_hw_spec_href(hw_spec_uid), params=self._client._params(),
                                           headers=self._client._get_headers(), verify=False)
 
         if response.status_code == 200:
@@ -114,7 +114,7 @@ class HwSpec(WMLResource):
     #         client=self._client)
     #
     #     hw_spec_meta_json = json.dumps(hw_spec_meta)
-    #     href = self._href_definitions.get_hw_specs_href()
+    #     href = self._client.service_instance._href_definitions.get_hw_specs_href()
     #
     #     if not self._ICP:
     #         creation_response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), data=hw_spec_meta_json)
@@ -154,7 +154,7 @@ class HwSpec(WMLResource):
             params.update({'name': name})
 
         # Todo provide api to return
-        href = self._href_definitions.get_hw_specs_href()
+        href = self._client.service_instance._href_definitions.get_hw_specs_href()
         # Todo include space_id/project_id once https://github.ibm.com/ax/planning/issues/7493 is fixed
         if not self._ICP:
             response = requests.get(href, params, headers=self._client._get_headers())
@@ -312,11 +312,11 @@ class HwSpec(WMLResource):
         parameters = self._client._params(skip_space_project_chk=True)
         parameters.update(name=hw_spec_name)
         if not self._ICP:
-            response = requests.get(self._href_definitions.get_hw_specs_href(),
+            response = requests.get(self._client.service_instance._href_definitions.get_hw_specs_href(),
                                     params=parameters,
                                     headers=self._client._get_headers())
         else:
-            response = requests.get(self._href_definitions.get_hw_specs_href(),
+            response = requests.get(self._client.service_instance._href_definitions.get_hw_specs_href(),
                                     params=parameters,
                                     headers=self._client._get_headers(), verify=False)
         if response.status_code == 200:
@@ -351,10 +351,10 @@ class HwSpec(WMLResource):
     #     HwSpec._validate_type(hw_spec_uid, u'hw_spec_uid', STR_TYPE, True)
     #
     #     if not self._ICP:
-    #         response = requests.delete(self._href_definitions.get_hw_spec_href(hw_spec_uid), params=self._client._params(),
+    #         response = requests.delete(self._client.service_instance._href_definitions.get_hw_spec_href(hw_spec_uid), params=self._client._params(),
     #                                 headers=self._client._get_headers())
     #     else:
-    #         response = requests.delete(self._href_definitions.get_hw_spec_href(hw_spec_uid), params=self._client._params(),
+    #         response = requests.delete(self._client.service_instance._href_definitions.get_hw_spec_href(hw_spec_uid), params=self._client._params(),
     #                                   headers=self._client._get_headers(), verify=False)
     #     if response.status_code == 200:
     #         return self._get_required_element_from_response(response.json())
@@ -380,9 +380,6 @@ class HwSpec(WMLResource):
                           }
             elif self._client.default_project_id is not None:
                 if self._client.WSD:
-
-                    href = "/v2/assets/" + response_data['metadata']['asset_id'] + "?" + "project_id=" + response_data['metadata']['project_id']
-
                     new_el = {'metadata': {
                                            'name': response_data['metadata']['name'],
                                            'asset_id': response_data['metadata']['asset_id'],
