@@ -305,7 +305,7 @@ class PlatformSpaces(WMLResource):
         return response
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def get_details(self, space_id=None, limit=None):
+    def get_details(self, space_id=None, limit=None, asynchronous=False, get_all=False):
         """
            Get metadata of stored space(s)
 
@@ -316,6 +316,10 @@ class PlatformSpaces(WMLResource):
                    **type**: str\n
                 #. **limit**: Applicable when space_id is not provided. If space_id is provided, this will be ignored \n
                    **type**: str\n
+                #. **asynchronous**:  if True, it will work as a generator (optional)\n
+                   **type**: bool\n
+                #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
+                   **type**: bool\n
 
            **Output**
 
@@ -326,6 +330,11 @@ class PlatformSpaces(WMLResource):
            **Example**
 
             >>> space_details = client.spaces.get_details(space_uid)
+            >>> space_details = client.spaces.get_details(limit=100)
+            >>> space_details = client.spaces.get_details(limit=100, get_all=True)
+            >>> space_details = []
+            >>> for entry in client.spaces.get_details(limit=100, asynchronous=True, get_all=True):
+            >>>    space_details.extend(entry)
         """
 
         space_id = str_type_conv(space_id)
@@ -348,7 +357,9 @@ class PlatformSpaces(WMLResource):
                                                    'spaces',
                                                    summary=False,
                                                    pre_defined=False,
-                                                   skip_space_project_chk=True)
+                                                   skip_space_project_chk=True,
+                                                   _async=asynchronous,
+                                                   _all=get_all)
 
     def list(self, limit=None, member=None, roles=None):
         """
