@@ -160,7 +160,7 @@ class RemoteTrainingSystem(WMLResource):
             print("Remote training system deleted")
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def get_details(self, remote_training_system_id=None, limit=None):
+    def get_details(self, remote_training_system_id=None, limit=None, asynchronous=False, get_all=False):
         """
             Get metadata of the given remote training system. if no remote_training_systems_id is specified all 
             remote training systems metadata is returned.
@@ -172,6 +172,10 @@ class RemoteTrainingSystem(WMLResource):
                    **type**: str\n
                 #. **limit**:  limit number of fetched records (optional)\n
                    **type**: int\n
+                #. **asynchronous**:  if True, it will work as a generator (optional)\n
+                   **type**: bool\n
+                #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
+                   **type**: bool\n
 
            **Output**
 
@@ -187,6 +191,11 @@ class RemoteTrainingSystem(WMLResource):
 
              >>> details = client.remote_training_systems.get_details(remote_training_systems_id)
              >>> details = client.remote_training_systems.get_details()
+             >>> details = client.remote_training_systems.get_details(limit=100)
+             >>> details = client.remote_training_systems.get_details(limit=100, get_all=True)
+             >>> details = []
+             >>> for entry in client.remote_training_systems.get_details(limit=100, asynchronous=True, get_all=True):
+             >>>    details.extend(entry)
          """
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError("Not supported in this release")
@@ -198,7 +207,11 @@ class RemoteTrainingSystem(WMLResource):
 
         href = self._client.service_instance._href_definitions.remote_training_systems_href()
 
-        return self._get_artifact_details(href, remote_training_system_id, limit, 'remote_training_systems')
+        if remote_training_system_id is None:
+            return self._get_artifact_details(href, remote_training_system_id, limit, 'remote_training_systems',
+                                              _async=asynchronous, _all=get_all)
+        else:
+            return self._get_artifact_details(href, remote_training_system_id, limit, 'remote_training_systems')
     
     def list(self, limit=None):
         """
