@@ -308,11 +308,15 @@ class Repository(WMLResource):
                                 - scikit-learn (.tar.gz)
                                 - tensorflow (.tar.gz)
                                 - spss (.str)
+                                - spark (.tar.gz)
                             - directory containing model file(s):\n
                                 - scikit-learn
                                 - xgboost
                                 - tensorflow
                             - unique id of trained model
+
+                    #. **Example**:
+                    >>> published_model_details = wml_client.repository.store_model(model="rf_model_0.4.tar.gz", meta_props=metadata)
                     #. **training_data**:  Spark DataFrame supported for spark models. Pandas dataframe, numpy.ndarray or array supported for scikit-learn models\n
                        **type**: spark dataframe, pandas dataframe, numpy.ndarray or array\n
 
@@ -1088,7 +1092,7 @@ class Repository(WMLResource):
         return details
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def get_model_details(self, model_uid=None, limit=None):
+    def get_model_details(self, model_uid=None, limit=None, asynchronous=False, get_all=False):
         """
            Get metadata of stored model. If model_uid is not specified returns all models metadata.
 
@@ -1099,6 +1103,10 @@ class Repository(WMLResource):
                    **type**: str\n
                 #. **limit**:  limit number of fetched records (optional)\n
                    **type**: int\n
+                #. **asynchronous**:  if True, it will work as a generator (optional)\n
+                   **type**: bool\n
+                #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
+                   **type**: bool\n
 
            **Output**
 
@@ -1113,9 +1121,15 @@ class Repository(WMLResource):
 
             >>> model_details = client.repository.get_model_details(model_uid)
             >>> models_details = client.repository.get_model_details()
+            >>> models_details = client.repository.get_model_details(limit=100)
+            >>> models_details = client.repository.get_model_details(limit=100, get_all=True)
+            >>> models_details = []
+            >>> for details in client.repository.get_model_details(limit=100, asynchronous=True, get_all=True):
+            >>>     models_details.append(details)
         """
 
-        return self._client._models.get_details(model_uid, limit)
+        return self._client._models.get_details(model_uid, limit,
+                                                asynchronous=asynchronous, get_all=get_all)
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_model_revision_details(self, model_uid, rev_uid):
@@ -1959,7 +1973,7 @@ class Repository(WMLResource):
              print('Note: Only first {} records were displayed. To display more use more specific list functions.'.format(_DEFAULT_LIST_LENGTH))
 
 
-    def list_models(self, limit=None):
+    def list_models(self, limit=None, asynchronous=False, get_all=False):
         """
            List stored models. If limit is set to None there will be only first 50 records shown.
 
@@ -1968,6 +1982,10 @@ class Repository(WMLResource):
            .. important::
                 #. **limit**:  limit number of fetched records\n
                    **type**: int\n
+                #. **asynchronous**:  if True, it will work as a generator (optional)\n
+                   **type**: bool\n
+                #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
+                   **type**: bool\n
 
            **Output**
 
@@ -1978,9 +1996,11 @@ class Repository(WMLResource):
            **Example**
 
             >>> client.repository.list_models()
+            >>> client.repository.list_models(limit=100)
+            >>> client.repository.list_models(limit=100, get_all=True)
+            >>> [entry for entry in client.repository.list_models(limit=100, asynchronous=True, get_all=True)]
         """
-
-        self._client._models.list(limit=limit)
+        return self._client._models.list(limit=limit, asynchronous=asynchronous, get_all=get_all)
 
     def list_experiments(self, limit=None):
         """
