@@ -188,6 +188,7 @@ class AbstractTestTSAsync(abc.ABC):
     def test_08b_get_metrics(self):
         metrics = self.wml_client.training.get_metrics(self.run_id)
         self.assertIsNotNone(metrics)
+        self.assertGreater(len(metrics), 0)
 
     # # GET PIPELINE FOR TS IS NOT SUPPORTED
     # def test_09_predict_using_fitted_pipeline(self):
@@ -203,9 +204,9 @@ class AbstractTestTSAsync(abc.ABC):
 
         self.assertGreater(len(pipelines_summary), 0, msg=f"Summary is empty:\n {pipelines_summary.to_string()}")
         if 'max_number_of_estimators' in self.experiment_info and self.experiment_info:
-            nb_gen_pipelines = 4 * self.experiment_info['max_number_of_estimators']
-            self.assertEqual(len(pipelines_summary), nb_gen_pipelines,
-                             msg=f"Incorrect pipelines in summary:\n {pipelines_summary.to_string()}")
+            nb_gen_pipelines = self.experiment_info['max_number_of_estimators']
+            self.assertEqual(len(chosen_models_summary), nb_gen_pipelines,
+                             msg=f"Incorrect winning pipelines in summary:\n {pipelines_summary.to_string()}")
 
     def test_11__get_data_connections__return_a_list_with_data_connections_with_optimizer_params(self):
         data_connections = self.remote_auto_pipelines.get_data_connections()
@@ -299,12 +300,12 @@ class AbstractTestTSAsync(abc.ABC):
             AbstractTestTSAsync.service = WebService(source_wml_credentials=self.wml_credentials,
                                                      source_space_id=self.space_id,
                                                      target_wml_credentials=self.wml_credentials,
-                                                     target_space_id=self.target_space_id)
+                                                     target_space_id=AbstractTestTSAsync.target_space_id)
         else:
             AbstractTestTSAsync.service = WebService(source_wml_credentials=self.wml_credentials,
                                                      source_project_id=self.project_id,
                                                      target_wml_credentials=self.wml_credentials,
-                                                     target_space_id=self.target_space_id)
+                                                     target_space_id=AbstractTestTSAsync.target_space_id)
 
         self.assertIsInstance(AbstractTestTSAsync.service, WebService, msg="Deployment is not of WebService type.")
         self.assertIsInstance(AbstractTestTSAsync.service._source_workspace, WorkSpace,
