@@ -4,7 +4,7 @@ import ibm_boto3
 
 from ibm_watson_machine_learning.helpers.connections import DataConnection, ContainerLocation, S3Location
 from ibm_watson_machine_learning.utils.autoai.errors import WMLClientError
-from ibm_watson_machine_learning.tests.utils import bucket_exists, is_cp4d, create_bucket
+from ibm_watson_machine_learning.tests.utils import bucket_exists, is_cp4d, create_bucket, save_data_to_container
 from ibm_watson_machine_learning.tests.autoai.abstract_tests_classes import (
     AbstractTestAutoAIRemote)
 
@@ -58,8 +58,9 @@ class TestAutoAIRemote(AbstractTestAutoAIRemote, unittest.TestCase):
         self.assertIsInstance(self.connection_id, str)
 
     def test_00d_write_data_to_container(self):
-        # note writing to project
-        pass
+        # writing to project
+        self.wml_client.set.default_project(self.project_id)
+        save_data_to_container(self.data_location, self.data_cos_path, self.wml_client)
 
     def test_02_DataConnection_setup(self):
         TestAutoAIRemote.data_connection = DataConnection(
