@@ -69,7 +69,7 @@ class TestAutoAIRemote(AbstractTestAutoAIRemote, unittest.TestCase):
         self.assertIsNotNone(obj=TestAutoAIRemote.results_connection)
 
     def test_02a_read_saved_remote_data_before_fit(self):
-        TestAutoAIRemote.data = self.data_connection.read(csv_separator=self.custom_separator)
+        TestAutoAIRemote.data = self.data_connection.read(excel_sheet=self.sheet_name)
         print("Data sample:")
         print(self.data.head())
         self.assertGreater(len(self.data), 0)
