@@ -71,6 +71,10 @@ class TestAutoAIRemote(unittest.TestCase):
 
     data_cos_path = 'data/iris_dataset_different_delimeter.csv'
 
+    prediction_column = 'species'
+    X_values = None
+    y_values = None
+
     results_cos_path = 'results_wml_autoai'
 
     OPTIMIZER_NAME = 'Iris wml_autoai multiclass test'
@@ -158,11 +162,11 @@ class TestAutoAIRemote(unittest.TestCase):
 
         self.assertIsNotNone(obj=TestAutoAIRemote.data_connection)
 
-    def test_02a_read_saved_remote_data_before_fit(self):
-        TestAutoAIRemote.data = self.data_connection.read(csv_separator=self.custom_separator)
-        print("Data sample:")
-        print(self.data.head())
-        self.assertGreater(len(self.data), 0)
+    # def test_02a_read_saved_remote_data_before_fit(self):
+    #     TestAutoAIRemote.data = self.data_connection.read(csv_separator=self.custom_separator)
+    #     print("Data sample:")
+    #     print(self.data.head())
+    #     self.assertGreater(len(self.data), 0)
 
 
     #################################
@@ -174,7 +178,7 @@ class TestAutoAIRemote(unittest.TestCase):
             name=self.OPTIMIZER_NAME,
             desc='test description',
             prediction_type=self.experiment.PredictionType.MULTICLASS,
-            prediction_column='species',
+            prediction_column=self.prediction_column,
             scoring=self.experiment.Metrics.ACCURACY_SCORE,
             holdout_size=0.15,
             max_number_of_estimators=1,
@@ -220,6 +224,9 @@ class TestAutoAIRemote(unittest.TestCase):
         print(self.train_data.head())
         self.assertGreater(len(self.train_data), 0)
 
+        TestAutoAIRemote.X_values = self.train_data.drop([self.prediction_column], axis=1)[:10].values
+        TestAutoAIRemote.y_values = self.train_data[self.prediction_column][:10]
+
     def test_07_get_run_status(self):
         status = self.remote_auto_pipelines.get_run_status()
         self.assertEqual(status, "completed", msg="AutoAI run didn't finished successfully. Status: {}".format(status))
@@ -279,7 +286,7 @@ class TestAutoAIRemote(unittest.TestCase):
                 lale_pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name=pipeline_name)
                 self.assertIsInstance(lale_pipeline, TrainablePipeline)
                 predictions = lale_pipeline.predict(
-                    X=self.train_data.values[:1])
+                    X=self.X_values[:1])
                 print(predictions)
                 self.assertGreater(len(predictions), 0, msg=f"Returned prediction for {pipeline_name} are empty")
             except:
@@ -332,7 +339,7 @@ class TestAutoAIRemote(unittest.TestCase):
         pipeline_name = summary.index.values[0]
         historical_pipeline = self.historical_opt.get_pipeline(pipeline_name, astype=self.experiment.PipelineTypes.SKLEARN)
         print(type(historical_pipeline))
-        predictions = historical_pipeline.predict(self.train_data.values[-2:])
+        predictions = historical_pipeline.predict(self.X_values[-2:])
         print(predictions)
         self.assertGreater(len(predictions), 0, msg="Empty predictions")
 
