@@ -25,7 +25,7 @@ from ibm_watson_machine_learning.utils.autoai.enums import PositiveLabelClass, T
 
 
 
-# @unittest.skip('not yet supported')
+@unittest.skip('S3 inline credentials are deprecated')
 class TestAutoAIRemote(unittest.TestCase):
     """
     The test can be run on CLOUD, WMLS and CPD (not tested)
