@@ -191,7 +191,7 @@ class TestAutoAIRemote(unittest.TestCase):
             scoring=self.experiment.Metrics.LOG_LOSS,
             train_sample_columns_index_list=self.train_sample_columns_index_list,
             text_processing=True,
-            word2vec_feature_number=15,
+            word2vec_feature_number=self.word2vec_feature_number,
             autoai_pod_version=self.pod_version
         )
 
