@@ -88,7 +88,7 @@ class Training(WMLResource):
             raise WMLClientError(u'Getting trained model status failed. Unable to get model details for training_uid: \'{}\'.'.format(training_uid))
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def get_details(self, training_uid=None, limit=None):
+    def get_details(self, training_uid=None, limit=None, asynchronous=False, get_all=False):
         """
         Get metadata of training(s). If training_uid is not specified returns all model spaces metadata.
 
@@ -99,6 +99,10 @@ class Training(WMLResource):
                **type**: str\n
             #. **limit**:  limit number of fetched records (optional)\n
                **type**: int\n
+            #. **asynchronous**:  if True, it will work as a generator (optional)\n
+               **type**: bool\n
+            #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
+               **type**: bool\n
 
         **Output**
 
@@ -114,6 +118,11 @@ class Training(WMLResource):
 
          >>> training_run_details = client.training.get_details(training_uid)
          >>> training_runs_details = client.training.get_details()
+         >>> training_runs_details = client.training.get_details(limit=100)
+         >>> training_runs_details = client.training.get_details(limit=100, get_all=True)
+         >>> training_runs_details = []
+         >>> for entry in client.training.get_details(limit=100, asynchronous=True, get_all=True):
+         >>>    training_runs_details.extend(entry)
         """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
@@ -122,7 +131,11 @@ class Training(WMLResource):
 
         url = self._client.service_instance._href_definitions.get_trainings_href()
 
-        return self._get_artifact_details(url, training_uid, limit, 'trained models')
+        if training_uid is None:
+            return self._get_artifact_details(url, training_uid, limit, 'trained models', _async=asynchronous, _all=get_all)
+
+        else:
+            return self._get_artifact_details(url, training_uid, limit, 'trained models')
 
     @staticmethod
     @docstring_parameter({'str_type': STR_TYPE_NAME})
@@ -496,15 +509,19 @@ class Training(WMLResource):
             self._logger.debug(u'Response({}): {}'.format(state, run_details))
             return self.get_details(trained_model_guid)
 
-    def list(self, limit=None):
+    def list(self, limit=None, asynchronous=False, get_all=False):
         """
            List stored trainings. If limit is set to None there will be only first 50 records shown.
 
            **Parameters**
 
            .. important::
-                #. **limit**:  limit number of fetched records\n
+                #. **limit**:  limit number of fetched records at once\n
                    **type**: int\n
+                #. **asynchronous**:  if True, it will work as a generator (optional)\n
+                   **type**: bool\n
+                #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
+                   **type**: bool\n
 
            **Output**
 
@@ -515,14 +532,29 @@ class Training(WMLResource):
            **Example**
 
             >>> client.training.list()
+            >>> training_runs_df = client.training.list(limit=100)
+            >>> training_runs_df = client.training.list(limit=100, get_all=True)
+            >>> training_runs_df = []
+            >>> for entry in client.training.list(limit=100, asynchronous=True, get_all=True):
+            >>>    training_runs_df.extend(entry)
         """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
-        details = self.get_details(limit=limit)
-        resources = details[u'resources']
-        values = [(m[u'metadata'].get('id', m[u'metadata'].get('guid')), m[u'entity'][u'status'][u'state'], m[u'metadata'][u'created_at']) for m in resources]
+        def preprocess_details(details: dict):
+            resources = details[u'resources']
+            values = [(m[u'metadata'].get('id', m[u'metadata'].get('guid')), m[u'entity'][u'status'][u'state'],
+                       m[u'metadata'][u'created_at']) for m in resources]
 
-        self._list(values, [u'ID (training)', u'STATE', u'CREATED'], limit, 100, sort_by=None)
+            return self._list(values, [u'ID (training)', u'STATE', u'CREATED'], limit=None,
+                              default_limit=100000, sort_by=None)
+
+        if asynchronous:
+            return (preprocess_details(details) for details in self.get_details(
+                limit=limit, asynchronous=asynchronous, get_all=get_all))
+
+        else:
+            details = self.get_details(limit=limit, get_all=get_all)
+            return preprocess_details(details)
 
     def list_subtrainings(self, training_uid):
         """
