@@ -61,7 +61,9 @@ __all__ = [
     'TSNotSupported',
     'InvalidDataAsset',
     'ParamOutOfRange',
-    'CannotConnectToWebsocket'
+    'CannotConnectToWebsocket',
+    'TestDataNotPresent',
+    'NoAutomatedHoldoutSplit'
 ]
 
 from ibm_watson_machine_learning.utils import WMLClientError
@@ -324,3 +326,17 @@ class ParamOutOfRange(WMLClientError, ValueError):
 class CannotConnectToWebsocket(WMLClientError, ValueError):
     def __init__(self, n):
         WMLClientError.__init__(self, f"{n} times connecting to websocket failed.")
+
+
+class TestDataNotPresent(WMLClientError, ValueError):
+    def __init__(self, reason):
+        WMLClientError.__init__(self, "User defined (test / holdout) data is not present for this AutoAI experiment.",
+                                reason)
+
+
+class NoAutomatedHoldoutSplit(WMLClientError, ValueError):
+    def __init__(self, reason):
+        WMLClientError.__init__(self, "AutoAI experiment was performed with user defined holdout."
+                                      "To recreate holdout split, please use test data connection."
+                                      "You can call optimizer.get_test_data_connections().",
+                                reason)
