@@ -412,16 +412,25 @@ class NextRunDetailsGenerator:
             raise StopIteration
 
 
-def preprocess_request_json(request_json: Dict, space_id: str) -> Dict:
-    """Removes unused parts of request.json file got from autoai training.
-    Allow to further store model in user space."""
-    # note: if training was on project_id, change it to space_id as we can deploy only on space
-    if 'project_id' in request_json:
-        request_json.pop('project_id')
+def preprocess_request_json(request_json: Dict) -> Dict:
+    """Removes S3 types from older trainings and replace them with container type."""
+    if "content_location" in request_json:
+        if "location" in request_json["content_location"]:
+            if request_json["content_location"]["location"].get("type") == 's3':
+                request_json["content_location"]["location"]["type"] = 'container'
+
+        if request_json["content_location"].get("type") == 's3':
+            request_json["content_location"]["type"] = 'container'
+
+    if "training_data_references" in request_json:
+        for ref in request_json["training_data_references"]:
+            if ref.get("type") == 's3':
+                ref['type'] = 'container'
+
+            if "location" in ref:
+                if ref['location'].get("type") == 's3':
+                    ref['location']['type'] = 'container'
 
-    request_json['space_id'] = space_id
-    request_json.pop('pipeline')  # not needed for other space
-    # --- end note
     return request_json
 
 
@@ -502,7 +511,12 @@ def prepare_auto_ai_model_to_publish_notebook_normal_scenario(
 
     request_json: Dict[str, dict] = json.loads(request_str)
     if 'connection' in run_params['entity']['results_reference']:
-        request_json['content_location']['connection'] = run_params['entity']['results_reference']['connection']
+        if "content_location" in request_json:
+            if "location" in request_json["content_location"]:
+                if request_json["content_location"]["location"].get("type") != 's3':
+                    request_json['content_location']['connection'] = run_params['entity']['results_reference']['connection']
+
+    request_json = preprocess_request_json(request_json)
 
     artifact_name = f"autoai_sdk{os.path.sep}{pipeline_model}.pickle"
 
@@ -639,10 +653,19 @@ def prepare_auto_ai_model_to_publish_normal_scenario(
     If cp4d: Dictionary with model schema and artifact name to upload, stored temporally in the user local file system.
     else: path name to the stored model in COS
     """
-    request_json: Dict[str, dict] = download_request_json(run_params, pipeline_model, wml_client, result_reference)
+    try:
+        request_json: Dict[str, dict] = download_request_json(run_params, pipeline_model, wml_client, result_reference)
+    except:
+        raise MissingPipeline(
+            pipeline_model,
+            reason="The name of the pipeline is incorrect or there are no pipelines computed."
+        )
     # note: fill connection details
     if 'connection' in run_params['entity']['results_reference']:
-        request_json['content_location']['connection'] = run_params['entity']['results_reference']['connection']
+        if "content_location" in request_json:
+            if "location" in request_json["content_location"]:
+                if request_json["content_location"]["location"].get("type") != 's3' and request_json["content_location"]["location"].get("type") != 'container':
+                    request_json['content_location']['connection'] = run_params['entity']['results_reference']['connection']
 
     artifact_name = f"autoai_sdk{os.path.sep}{pipeline_model}.pickle"
 
@@ -913,23 +936,42 @@ def try_import_lale():
                                        reason="lale failed to install. Please install it manually.")
 
 
-def try_import_autoai_libs():
+def try_import_autoai_libs(minimum_version: str = None):
     """
     Check if autoai_libs package is installed in local environment, if not, just download and install it.
     """
+    package = {'name': 'autoai-libs'}
+    default_version = '1.12.14'
+
+    if minimum_version is not None:
+        default_version = minimum_version
+
+    def install_autoai_libs(version):
+        """Try to install autoai-libs via pip."""
+        try:
+            check_call([executable, "-m", "pip", "install", f"autoai_libs>={version}"])
+
+        except Exception as e:
+            raise CannotInstallLibrary(value_name=e,
+                                       reason=f"autoai_libs>={version} failed to install. Please install it manually.")
+
     try:
         import autoai_libs
 
+        if minimum_version is not None:
+            try:
+                installed_module_version = fallback_to_pip_for_version_check(package)
+
+            except Exception:
+                installed_module_version = pkg_resources.get_distribution(package['name']).version
+
+            if version.parse(installed_module_version) < version.parse(minimum_version):
+                install_autoai_libs(version=minimum_version)
+
     except ImportError:
         warn(f"\"autoai_libs\" package is not installed. "
              f"This is the needed dependency for pipeline model refinery, we will try to install it now...")
-
-        try:
-            check_call([executable, "-m", "pip", "install", "autoai_libs>=1.11.0"])
-
-        except Exception as e:
-            raise CannotInstallLibrary(value_name=e,
-                                       reason="autoai_libs>=1.11.0 failed to install. Please install it manually.")
+        install_autoai_libs(version=default_version)
 
 
 def try_import_tqdm():
@@ -1383,8 +1425,9 @@ def create_summary(details: dict, scoring: str) -> 'DataFrame':
                         f"training_{scoring}_(optimized)"
                 }, axis='columns')
         elif is_ts_metrics:
+            metrics_names = get_metrics_names()
             pipelines = pipelines.sort_values(
-                by=['Winner'] + [get_metrics_names()[0]], ascending=False)
+                by=['Winner'] + ([metrics_names[0]] if len(metrics_names) > 0 else []), ascending=False)
 
     # note: sometimes backend will not return 'training_' prefix to the metric
     except KeyError:
@@ -1594,11 +1637,10 @@ def download_request_json(run_params: dict, model_name: str, wml_client, results
 
     pipeline_info = run_params['entity']['status'].get('metrics')[-1]
     schema_path = f"{pipeline_info['context']['intermediate_model']['schema_location']}"
+    model_number = model_name.split('_')[-1]
     if is_ml_metrics:
-        model_number = model_name.split('_')[-1]
         model_output = chose_model_output(model_number)
     elif is_ts_metrics:
-        model_number = pipeline_info['context']['intermediate_model']['name'][1:]
         model_output = 'after_final_pipelines_generation'
     request_path = f"{schema_path.split('/data/')[0]}/assets/{run_id}_P{model_number}_{model_output}/resources/wml_model/request.json"
 
@@ -1640,6 +1682,7 @@ def download_request_json(run_params: dict, model_name: str, wml_client, results
                 request_str = f.read()
 
     request_json: Dict[str, dict] = json.loads(request_str)
+    request_json = preprocess_request_json(request_json)
 
     return request_json
 
