@@ -16,7 +16,7 @@ import requests
 import logging
 from ibm_watson_machine_learning.wml_client_error import MissingValue, WMLClientError, NoWMLCredentialsProvided, ApiRequestFailure, UnexpectedType, MissingMetaProp
 from ibm_watson_machine_learning.href_definitions import HrefDefinitions
-from ibm_watson_machine_learning.utils import get_type_of_details, STR_TYPE, str_type_conv
+from ibm_watson_machine_learning.utils import get_type_of_details, STR_TYPE, str_type_conv, NextResourceGenerator
 import urllib.parse
 import os
 import sys
@@ -165,11 +165,21 @@ class WMLResource:
         else:
             raise WMLClientError("The LIB_UID provided is not a valid model_definition/library")
 
-    def _get_artifact_details(self, base_url, uid, limit, resource_name, summary=None,pre_defined=None, query_params=None):
+    def _get_artifact_details(self, base_url, uid, limit, resource_name, summary=None,
+                              pre_defined=None, query_params=None, _async=False, _all=False):
         op_name = 'getting {} details'.format(resource_name)
 
         if uid is None:
-            return self._get_with_or_without_limit(url=base_url, limit=limit, op_name=resource_name,summary=summary,pre_defined=pre_defined,query_params=query_params)
+            return self._get_with_or_without_limit(
+                url=base_url,
+                limit=limit,
+                op_name=resource_name,
+                summary=summary,
+                pre_defined=pre_defined,
+                query_params=query_params,
+                _async=_async,
+                _all=_all
+            )
         else:
             # if not is_uid(uid):
             #     raise WMLClientError(u'Failure during {}, invalid uid: \'{}\''.format(op_name, uid)) # TODO
@@ -200,7 +210,7 @@ class WMLResource:
             return self._handle_response(200, op_name, response_get)
 
     def _get_with_or_without_limit(self, url, limit, op_name, summary, pre_defined, revision=None,
-                                   skip_space_project_chk=False, query_params=None):
+                                   skip_space_project_chk=False, query_params=None, _async=False, _all=False):
         if query_params is None:
             params = self._client._params(skip_space_project_chk)
         else:
@@ -215,9 +225,11 @@ class WMLResource:
         if limit is not None:
             if limit < 1:
                 raise WMLClientError('Limit cannot be lower than 1.')
-            elif limit > 1000:
-                raise WMLClientError('Limit cannot be larger than 1000.')
+            elif limit > 200:
+                raise WMLClientError('Limit cannot be larger than 200.')
             params.update({u'limit': limit})
+        else:
+            params.update({u'limit': 200})
 
         if revision is not None:
             if op_name == 'asset_revision':
@@ -225,53 +237,51 @@ class WMLResource:
             else:
                 params.update({u'rev': revision})
 
-        if len (params) > 0:
-            if not self._ICP:
-                response_get = requests.get(
-                    url,
-                    headers=self._client._get_headers(),
-                    params=params
-                )
-            else:
-                response_get = requests.get(
-                    url,
-                    headers=self._client._get_headers(),
-                    params=params,
-                    verify=False
-                )
-            return self._handle_response(200, op_name, response_get)
+        resources = []
+
+        href = "/".join(url.split('/')[3:])
+        url_2 = "/".join(url.split('/')[:3])
+        resource_generator = NextResourceGenerator(self._client, url_2, href, params, _all)
+
+        if _async:
+            return ({"resources": entry} for entry in resource_generator)
+
         else:
+            if _all:
+                for entry in resource_generator:
+                    resources.extend(entry)
+                return {
+                    "resources": resources
+                }
 
-            resources = []
-
-            while True:
+            else:
                 if not self._ICP:
                     response_get = requests.get(
                         url,
-                        headers=self._client._get_headers()
+                        headers=self._client._get_headers(),
+                        params=params
                     )
                 else:
                     response_get = requests.get(
                         url,
                         headers=self._client._get_headers(),
+                        params=params,
                         verify=False
                     )
 
                 result = self._handle_response(200, op_name, response_get)
-                resources.extend(result['resources'])
+                if 'resources' in result:
+                    resources.extend(result['resources'])
+
+                elif 'metadata' in result:
+                    resources.extend([result])
 
-                if 'next' not in result:
-                    break
                 else:
+                    resources.extend(result.get('results'))
 
-                    url = self._wml_credentials["url"]+result['next']['href']
-                    if('start=invalid' in url):
-                        break
-
-
-            return {
-                "resources": resources
-            }
+                return {
+                    "resources": resources
+                }
 
     def _get_no_space_artifact_details(self, base_url, uid, limit, resource_name, summary=None,pre_defined=None):
         op_name = 'getting {} details'.format(resource_name)
@@ -389,6 +399,21 @@ class WMLResource:
             table = tabulate([header] + values[:limit])
             print(table)
 
+        try:
+            import pandas as pd
+            if limit is None:
+                return pd.DataFrame(values[:default_limit], columns=header)
+
+            else:
+                return pd.DataFrame(values[:limit], columns=header)
+
+        except ImportError:
+            if limit is None:
+                return [header] + values[:default_limit]
+
+            else:
+                return [header] + values[:limit]
+
     def _wsd_list_assets(self, asset_type, limit=None):
         _DEFAULT_LIST_LENGTH = 50
         ##For CP4D, check if either spce or project ID is set
