@@ -18,6 +18,9 @@ from sklearn import metrics
 from skorch import NeuralNet
 from skorch.callbacks import EpochScoring
 from skorch.exceptions import NotInitializedError
+from skorch.dataset import CVSplit
+from skorch.dataset import Dataset
+from skorch.helper import predefined_split
 
 from ibmfl.model.fl_model import FLModel
 from ibmfl.model.model_update import ModelUpdate
@@ -122,7 +125,7 @@ class PytorchFLModel(FLModel):
         model.initialize()
         return model
 
-    def fit_model(self, train_data, fit_params=None, **kwargs):
+    def fit_model(self, train_data, fit_params=None, validation_data=None, **kwargs):
         """
         Fits current model with provided training data.
 
@@ -142,17 +145,37 @@ class PytorchFLModel(FLModel):
         batch_size = 128
         epochs = 1
         lr = 0.01
+        train_split = None
         optimizer_params = {}
         hyperparams = fit_params.get('hyperparams', {}) if fit_params else {}
+        party_params = kwargs.get('local_params', {}) or {} if fit_params else {}
 
         if hyperparams:
             local_params = hyperparams.get('local', {}) or {}
             training_hp = local_params.get('training', {}) or {}
-            
+
             epochs = training_hp.get('epochs', epochs)
             batch_size = training_hp.get('batch_size', batch_size)
             lr = training_hp.get('lr', lr)
-            
+
+            if 'validation_split' in training_hp:
+                validation_split = training_hp.get('validation_split')
+                try:
+                    if float(validation_split) != 0:
+                        train_split = CVSplit(float(validation_split), random_state=42)
+                except (TypeError, ValueError):
+                    raise ValueError("Validation split cannot be a NoneType")
+            if 'validation_split' in party_params:
+                validation_split = party_params.get('validation_split')
+                try:
+                    if float(validation_split) != 0:
+                        train_split = CVSplit(float(validation_split), random_state=42)
+                except (TypeError, ValueError):
+                    raise ValueError("Validation split cannot be a NoneType")
+            if validation_data is not None:
+                validation_ds = Dataset(validation_data[0], validation_data[1])
+                train_split = predefined_split(validation_ds)
+
             if 'optimizer' in local_params:
                 optimizer = local_params['optimizer']
                 if isinstance(optimizer, str):
@@ -189,7 +212,7 @@ class PytorchFLModel(FLModel):
 
             if 'optimizer_params' in local_params:
                 optimizer_params = local_params['optimizer_params']
-        self.model.set_params(batch_size=batch_size, lr=lr, **optimizer_params)
+        self.model.set_params(batch_size=batch_size, lr=lr, train_split=train_split, **optimizer_params)
 
         try:
             if type(train_data) is tuple:
@@ -638,9 +661,9 @@ class PytorchFLModel(FLModel):
         :return: The resulting loss.
         :rtype: `float`
         """
-        
+
         metrics_list = [PytorchFLModel.loss]
         orig_loss_value = self.evaluate(dataset, eval_metrics=metrics_list)[
                     'loss']
-        
+
         return orig_loss_value
