@@ -1,3 +1,11 @@
+"""
+IBM Confidential
+OCO Source Materials
+5737-H76, 5725-W78, 5900-A1R
+(c) Copyright IBM Corp. 2020 All Rights Reserved.
+The source code for this program is not published or otherwise divested of its trade secrets,
+irrespective of what has been deposited with the U.S. Copyright Office.
+"""
 #!/usr/bin/env python3
 import os
 import sys
@@ -22,8 +30,8 @@ def process_heartbeat(kwargs):
             if version_details[1] >= "202108":
                 return "cpd402"
             else: 
-                return "cpd35"
-        if service_version.startswith("353"):
+                return "cpd401"
+        if service_version.startswith("35"):
             return "cpd35"
 
         return "cloud"
@@ -59,6 +67,7 @@ class Party:
         'cloud':"/cloud/ibmfl/__init__.py",
         'cpd35':"/cpd35/ibmfl/__init__.py",
         'cpd402':"/cpd402/ibmfl/__init__.py",
+        'cpd401':"/cpd401/ibmfl/__init__.py",
     } 
 
     def __init__(self, **kwargs):
